@@ -12,7 +12,7 @@ extends 'LittleORM::Model';
 has 'id' => ( metaclass => 'LittleORM::Meta::Attribute',
 	      isa => 'Int',
 	      is => 'rw',
-	      description => { primary_key => 1 } );
+	      description => { primary_key => 1, db_field_type => 'int' } );
 
 
 42;
